================
Feature requests
================

To request a new feature, you should create a document similar to other feature requests. And contribute it to this directory using the next instruction_.

If you don't have time to contribute your feature request via gerrit, please contact Boris Pavlovic (boris@pavlovic.me)

.. _instruction:  http://rally.readthedocs.org/en/latest/contribute.html#how-to-contribute
